<?php

/**
  * Languages tab for admin panel, AdminLanguages.php
  * @category admin
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */

class AdminLanguages extends AdminTab
{
	public function __construct()
	{
	 	$this->table = 'lang';
	 	$this->className = 'Language';
	 	$this->lang = false;
	 	$this->edit = true;
 		
 		$this->fieldImageSettings = array('name' => 'flag', 'dir' => 'l');
		
		$this->fieldsDisplay = array(
		'id_lang' => array('title' => $this->l('ID'), 'align' => 'center', 'width' => 25),
		'flag' => array('title' => $this->l('Logo'), 'align' => 'center', 'image' => 'l', 'orderby' => false, 'search' => false),
		'name' => array('title' => $this->l('Name'), 'width' => 120),
		'iso_code' => array('title' => $this->l('ISO code'), 'width' => 70),
		'active' => array('title' => $this->l('Status'), 'align' => 'center', 'active' => 'status', 'type' => 'bool'));
	
		parent::__construct();
	}
	
	private function _fullCopy($source, $dest)
    {
        if (is_dir($source))
        {
            if (!file_exists($dest) AND !mkdir($dest))
				return false;
            $d = dir($source);
            while (false !== ($entry = $d->read()))
            {
                if ($entry == '.' || $entry == '..')
                    continue;
               
                $realEntry = $source.'/'.$entry;           
                if (is_dir($realEntry))
                {
                    $this->_fullCopy($realEntry, $dest.'/'.$entry);
                    continue;
                }
                copy($realEntry, $dest.'/'.$entry);
            }
			$d->close();
			return true;
        }
		else
            copy($source, $dest);
    }
	
	public function postProcess()
	{
		global $currentIndex;
		
		if (Tools::isSubmit('submitCopyLang'))
		{
			if (!($from = intval(Tools::getValue('from'))) OR !($to = intval(Tools::getValue('to'))))
				$this->_errors[] = $this->l('you must select 2 languages in order to copy data from one to another');
			elseif ($from == $to)
				$this->_errors[] = $this->l('you can\'t copy data from a language to itself');
			elseif (!Language::copyLanguageData($from, $to))
				$this->_errors[] = $this->l('an error occured while copying data');
			else
			{
				$fromIso = Language::getIsoById($from);
				$toIso = Language::getIsoById($to);
				$bool = @copy(dirname(__FILE__).'/../../errors/'.$fromIso.'.php', dirname(__FILE__).'/../../errors/'.$toIso.'.php');
				$bool &= @copy(dirname(__FILE__).'/../lang/'.$fromIso.'.php', dirname(__FILE__).'/../lang/'.$toIso.'.php');
				$bool &= @copy(_PS_THEME_DIR_.'lang/'.$fromIso.'.php', _PS_THEME_DIR_.'lang/'.$toIso.'.php');
				$bool &= $this->_fullCopy(dirname(__FILE__).'/../../mails/'.$fromIso, dirname(__FILE__).'/../../mails/'.$toIso);
				if ($bool)
					Tools::redirectLink($currentIndex.'&conf=14');
				$this->_errors[] = $this->l('a part of the data have been copied but some language files couldn\'t have been found or copied');
			}
		}
		elseif (isset($_GET['delete'.$this->table]))
		{
			if ($this->tabAccess['delete'] === '1')		 	
		 	{
				if (Validate::isLoadedObject($object = $this->loadObject()) AND isset($this->fieldImageSettings))
				{
					if ($object->id == Configuration::get('PS_LANG_DEFAULT'))
						$this->_errors[] = $this->l('you can\'t delete the default language');
					elseif ($object->delete())
						Tools::redirectAdmin($currentIndex.'&conf=1');
					else
						$this->_errors[] = Tools::displayError('an error occured during deletion');
				}
				else
					$this->_errors[] = Tools::displayError('an error occured while deleting object').' <b>'.$this->table.'</b> '.Tools::displayError('(cannot load object)');
			}
			else
				$this->_errors[] = Tools::displayError('You have not the right to delete something here.');
		}
		elseif(Tools::getValue('submitDel'.$this->table) AND isset($_POST[$this->table.'Box']))
		{
			if (in_array(Configuration::get('PS_LANG_DEFAULT'), $_POST[$this->table.'Box']))
				$this->_errors[] = $this->l('you can\'t delete the default language');
			else
				parent::postProcess();
		}
		else
			parent::postProcess();
	}
	
	public function displayList()
	{
		global $currentIndex;
		
		$this->displayWarning($this->l('If you delete a language, all the related translations in the database will be deleted at the same time.'));
		
		$defaultLanguage = new Language(intval(Configuration::get('PS_LANG_DEFAULT')));
		if (Validate::isLoadedObject($defaultLanguage))
			$this->displayWarning($this->l('Current default language is: ').$defaultLanguage->name.'. '.$this->l('You can change it in').' <a href="index.php?tab=AdminPreferences">'.$this->l('Preferences').'</a>.');
		
		parent::displayList();
		
		$languages = Language::getLanguages(false);
		echo '<br /><br />
		<form action="'.$currentIndex.'" method="post">
			<fieldset><legend><img src="../img/admin/copy.gif" />'.$this->l('Copy').'</legend>
				<p>'.$this->l('This form allow you to copy database data from a language to another. Be cautious, it will override the previous data !').'</p>
				<b>'.$this->l('From').'</b>&nbsp;&nbsp;&nbsp;
				<select name="from">
					<option value="0">-- '.$this->l('Choose').' --&nbsp;&nbsp;&nbsp;</option>';
		foreach	($languages AS $language)
			echo '<option value="'.$language['id_lang'].'">'.$language['name'].'</option>';
		echo '
				</select>&nbsp;&nbsp;&nbsp;
				<b>'.$this->l('to').'</b>&nbsp;&nbsp;&nbsp;
				<select name="to">
					<option value="0">-- '.$this->l('Choose').' --&nbsp;&nbsp;&nbsp;</option>';
		foreach	($languages AS $language)
			echo '<option value="'.$language['id_lang'].'">'.$language['name'].'</option>';
		echo '
				</select> 
				<div class="clear">&nbsp;</div>
				<div class="margin-form">
					<input type="submit" value="'.$this->l('   Copy   ').'" name="submitCopyLang" class="button" />
				</div>
			</fieldset>
		</form>';
	}
	
	public function displayForm()
	{
		global $currentIndex;		
		$obj = $this->loadObject(true);

		echo '
		<form action="'.$currentIndex.'&submitAdd'.$this->table.'=1" method="post" enctype="multipart/form-data">
		'.($obj->id ? '<input type="hidden" name="id_'.$this->table.'" value="'.$obj->id.'" />' : '').'
			<fieldset><legend><img src="../img/admin/world.gif" />'.$this->l('Languages').'</legend>
				<label>'.$this->l('Name:').' </label>
				<div class="margin-form">
					<input type="text" size="8" maxlength="32" name="name" value="'.$this->getFieldValue($obj, 'name').'" /> <sup>*</sup>
				</div>
				<label>'.$this->l('ISO code:').' </label>
				<div class="margin-form">
					<input type="text" size="4" maxlength="2" name="iso_code" value="'.$this->getFieldValue($obj, 'iso_code').'" /> <sup>*</sup>
					<p>'.$this->l('2 letters (eg. fr, en, sp...)').'</p>
				</div>
				<label>'.$this->l('Flag:').' </label>
				<div class="margin-form">
					<input type="file" name="flag" />
					<p>'.$this->l('Upload country flag from your computer').'</p>
				</div>
				<label>'.$this->l('Status:').' </label>
				<div class="margin-form">
					<input type="radio" name="active" id="active_on" value="1" '.((!$obj->id OR $this->getFieldValue($obj, 'active')) ? 'checked="checked" ' : '').'/>
					<label class="t" for="active_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
					<input type="radio" name="active" id="active_off" value="0" '.((!$this->getFieldValue($obj, 'active') AND $obj->id) ? 'checked="checked" ' : '').'/>
					<label class="t" for="active_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
					<p>'.$this->l('Allow or disallow this language to be chosen').'</p>
				</div>
				<div class="margin-form">
					<input type="submit" value="'.$this->l('   Save   ').'" name="submitAdd'.$this->table.'" class="button" />
				</div>
				<div class="small"><sup>*</sup> '.$this->l('required fields').'</div>
			</fieldset>
		</form>';
	}
}

?>