<?php

/**
  * General preferences tab for admin panel, AdminPreferences.php
  * @category admin
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */
  
class AdminPreferences extends AdminTab
{
	public function __construct()
	{
		global $cookie;
	
		$this->className = 'Configuration';
		$this->table = 'configuration';
		
 		$this->_fieldsGeneral = array(
			'PS_SHOP_NAME' => array('title' => $this->l('Shop name'), 'desc' => $this->l('Displayed in emails and page titles'), 'validation' => 'isGenericName', 'required' => true, 'size' => 30, 'type' => 'text'),
			'PS_SHOP_EMAIL' => array('title' => $this->l('Shop email'), 'desc' => $this->l('Displayed when customers receive emails'), 'validation' => 'isEmail', 'required' => true, 'size' => 30, 'type' => 'text'),
			'PS_REWRITING_SETTINGS' => array('title' => $this->l('Friendly URL'), 'desc' => $this->l('Enable only if your server allows URL rewriting (recommended)').'<p class="hint clear" style="display: block;">'.$this->l('If you turn on this feature, you must rename .htaccess.txt file to .htaccess').'</p><div class="clear"></div>', 'validation' => 'isBool', 'required' => true, 'cast' => 'intval', 'type' => 'bool'),
			'PS_LANG_DEFAULT' => array('title' => $this->l('Default language'), 'validation' => 'isUnsignedId', 'required' => true, 'cast' => 'intval', 'type' => 'select', 'identifier' => 'id_lang', 'list' => Language::getlanguages()), 
		'PS_COUNTRY_DEFAULT' => array('title' => $this->l('Default country'), 'validation' => 'isUnsignedId', 'required' => true, 'cast' => 'intval', 'type' => 'select', 'identifier' => 'id_country', 'list' => Country::getCountries(intval($cookie->id_lang))), 
			'PS_CARRIER_DEFAULT' => array('title' => $this->l('Default carrier'), 'validation' => 'isUnsignedId', 'required' => true, 'cast' => 'intval', 'type' => 'select', 'list' => Carrier::getCarriers(intval($cookie->id_lang), true), 'identifier' => 'id_carrier'), 
			'PS_CURRENCY_DEFAULT' => array('title' => $this->l('Default currency'), 'validation' => 'isUnsignedId', 'required' => true, 'cast' => 'intval', 'type' => 'select', 'list' => Currency::getCurrencies(), 'identifier' => 'id_currency'), 
			'PS_BASE_URI' => array('title' => $this->l('PS directory'), 'desc' => $this->l('PS directory on your web server with a trailing slash (eg. /)'), 'validation' => 'isGenericName', 'type' => 'text', 'size' => 20),
			'PS_HELPBOX' => array('title' => $this->l('Admin panel help boxes'), 'desc' => $this->l('Yellow help boxes under form fields'), 'validation' => 'isBool', 'cast' => 'intval', 'type' => 'bool'),
			'PS_CONDITIONS' => array('title' => $this->l('Check for conditions'), 'desc' => $this->l('Ask customers for accepting conditions before conclude the order'), 'validation' => 'isBool', 'cast' => 'intval', 'type' => 'bool'),
			'PS_GIFT_WRAPPING' => array('title' => $this->l('Suggest gift wrapping'), 'desc' => $this->l('Suggest to customer free gift wrapping'), 'validation' => 'isBool', 'cast' => 'intval', 'type' => 'bool'),
			'PS_RECYCLABLE_PACK' => array('title' => $this->l('Suggest recyclable pack'), 'desc' => $this->l('Suggest to customer recyclable pack'), 'validation' => 'isBool', 'cast' => 'intval', 'type' => 'bool'),
			'PS_VOUCHERS' => array('title' => $this->l('Enable Discounts'), 'desc' => $this->l('Enable the usage of vourchers'), 'validation' => 'isBool', 'cast' => 'intval', 'type' => 'bool')
		);
		
		$this->_fieldsTheme = array(
		'PS_THEME' => array('title' => $this->l('Theme'), 'validation' => 'isGenericName', 'type' => 'image', 'list' => $this->_getThemesList()));
		
		$this->_fieldsShop = array(
		'PS_SHOP_RCS' => array('title' => $this->l('RCS (french)'), 'validation' => 'isGenericName', 'size' => 30, 'type' => 'text'),
		'PS_SHOP_SIRET' => array('title' => $this->l('Siret (french)'), 'validation' => 'isGenericName', 'size' => 30, 'type' => 'text'),
		'PS_SHOP_ADDR1' => array('title' => $this->l('Address'), 'validation' => 'isGenericName', 'size' => 30, 'type' => 'text'),
		'PS_SHOP_ADDR2' => array('title' => '', 'validation' => 'isGenericName', 'size' => 30, 'type' => 'text'),
		'PS_SHOP_CODE' => array('title' => $this->l('Postcode'), 'validation' => 'isGenericName', 'size' => 6, 'type' => 'text'),
		'PS_SHOP_CITY' => array('title' => $this->l('City'), 'validation' => 'isGenericName', 'size' => 30, 'type' => 'text'),
		'PS_SHOP_COUNTRY' => array('title' => $this->l('Country'), 'validation' => 'isGenericName', 'size' => 30, 'type' => 'text'),
		'PS_SHOP_PHONE' => array('title' => $this->l('Phone'), 'validation' => 'isGenericName', 'size' => 30, 'type' => 'text'));
	
		parent::__construct();
	}
	
	public function postProcess()
	{
		global $currentIndex;
		
		if (isset($_POST['submitGeneral'.$this->table]))
			$this->_postConfig($this->_fieldsGeneral);
		elseif (isset($_POST['submitShop'.$this->table]))
			$this->_postConfig($this->_fieldsShop);
		elseif (isset($_POST['submitThemes'.$this->table]))
		{
			if ($val = Tools::getValue('PS_THEME'))
			{
			 	rewriteSettingsFile(NULL, $val, NULL);
			 	Tools::redirectAdmin($currentIndex.'&conf=6');
			}
			else
				$this->_errors[] = Tools::displayError('you must choose a graphical theme');
		}
	}
	
	/**
	  * Update settings in database and configuration files
	  *
	  * @params array $fields Fields settings
	  *
	  * @global string $currentIndex Current URL in order to keep current Tab
	  */
	protected function _postConfig($fields)
	{
		global $currentIndex;

		/* Check required fields */
		foreach ($fields AS $field => $values)
			if (isset($values['required']) AND $values['required'])
				if (($value = Tools::getValue($field)) == false AND (string)$value != '0')
					$this->_errors[] = Tools::displayError('field').' <b>'.$values['title'].'</b> '.Tools::displayError('is required');
		
		/* Check fields validity */
		foreach ($fields AS $field => $values)
			if (Tools::getValue($field))
			{
				$function = $values['validation'];
				if (!Validate::$function(Tools::getValue($field)))
					$this->_errors[] = Tools::displayError('field').' <b>'.$values['title'].'</b> '.Tools::displayError('is invalid');
			}
			
		if (!sizeof($this->_errors))
		{
			/* Write settings in configuration file */
			if (isset($_POST['submitGeneral'.$this->table]))
			{
				rewriteSettingsFile(isset($_POST['PS_BASE_URI']) ? $_POST['PS_BASE_URI'] : '', NULL, NULL);		
				unset($this->_fieldsGeneral['PS_BASE_URI']);
			}
			
			/* Update settings in database */
			foreach ($fields AS $field => $values)
			{
				$val = isset($values['cast']) ? $values['cast'](Tools::getValue($field)) : Tools::getValue($field);
				Configuration::updateValue($field, $val);
			}

			Tools::redirectAdmin($currentIndex.'&conf=6');
		}
	}
	
	public function display()
	{
		$this->displayFormGeneral();
		echo '<br /><br />';
		$this->displayFormThemes();
		echo '<br /><br />';
		$this->displayFormShop();
	}
	
	/**
	  * Return an array with themes and thumbnails
	  *
	  * @return array
	  */
	private function _getThemesList()
	{
		$dir = opendir(_PS_ALL_THEMES_DIR_);
		while ($folder = readdir($dir))
			if ($folder != '.' AND $folder != '..' AND file_exists(_PS_ALL_THEMES_DIR_.'/'.$folder.'/preview.jpg'))
				$themes[$folder]['name'] = $folder;
		closedir($dir);	
		return isset($themes) ? $themes : array();
	}
	
	/**
	  * Display configuration form
	  *
	  * @params string $name Form name
	  * @params array $fields Fields settings
	  *
	 * @global string $currentIndex Current URL in order to keep current Tab
	  */
	protected function _displayForm($name, $fields)
	{
		global $currentIndex;

		/* Preload configuration values from database ans config file */
		foreach ($fields AS $key => $field)
			$getConf[] = $key;
		if (isset($getConf['PS_BASE_URI'])) unset($getConf['PS_BASE_URI']);
		if (isset($getConf['PS_THEME'])) unset($getConf['PS_THEME']);
		$confValues = Configuration::getMultiple($getConf);
		$confValues['PS_BASE_URI'] = __PS_BASE_URI__;
		$confValues['PS_THEME'] = _THEME_NAME_;
		$confValues['db_type'] = _DB_TYPE_;
		$confValues['db_server'] = _DB_SERVER_;
		$confValues['db_name'] = _DB_NAME_;
		$confValues['db_prefix'] = _DB_PREFIX_;
		$confValues['db_user'] = _DB_USER_;
		$confValues['db_passwd'] = _DB_PASSWD_;

		echo '
		<form action="'.$currentIndex.'&submit'.ucfirst($name).$this->table.'=1" method="post" class="width3">
			<fieldset><legend><img src="../img/admin/tab-preferences.gif" />'.$name.'</legend>';
		
		$required = false;
		/* Display fields from $fields settings */
		foreach ($fields AS $key => $field)
		{
			/* Specific line for emails settings */
			if (get_class($this) == 'AdminEmails' AND $key == 'PS_MAIL_SERVER')
				echo '<div id="smtp" style="display: '.((isset($confValues['PS_MAIL_METHOD']) AND $confValues['PS_MAIL_METHOD'] == 2) ? 'block' : 'none').';">';
			if (isset($field['required']) AND $field['required'])
				$required = true;
			$val = Tools::getValue($key);
			if (!$val AND isset($confValues[$key])) $val = $confValues[$key];
			if (!in_array($field['type'], array('image', 'radio')) OR isset($field['show']))
				echo ($field['title'] ? '<label>'.$field['title'].':</label>' : '').'<div class="margin-form">';
			
			/* Display the appropriate input type for each field */
			switch ($field['type'])
			{
				case 'select':
					echo '
					<select name="'.$key.'">';
					foreach ($field['list'] AS $k => $value)
						echo '<option value="'.intval($value[$field['identifier']]).'"'.(($val == $value[$field['identifier']]) ? 'selected="selected"' : '').'>'.$value['name'].'</option>';
					echo '
					</select>';
					break;
					
				case 'bool':
					echo '<label class="t" for="'.$key.'_on"><img src="../img/admin/enabled.gif" alt="'.$this->l('Yes').'" title="'.$this->l('Yes').'" /></label>
					<input type="radio" name="'.$key.'" id="'.$key.'_on" value="1"'.($val ? ' checked="checked"' : '').' />
					<label class="t" for="'.$key.'_on"> '.$this->l('Yes').'</label>
					<label class="t" for="'.$key.'_off"><img src="../img/admin/disabled.gif" alt="'.$this->l('No').'" title="'.$this->l('No').'" style="margin-left: 10px;" /></label>
					<input type="radio" name="'.$key.'" id="'.$key.'_off" value="0" '.(!$val ? 'checked="checked"' : '').'/>
					<label class="t" for="'.$key.'_off"> '.$this->l('No').'</label>';
					break;
					
				case 'radio':
					foreach ($field['choices'] AS $cValue => $cKey)
						echo '<input type="radio" name="'.$key.'" id="'.$key.$cValue.'_on" value="'.intval($cValue).'"'.(($cValue == $val) ? ' checked="checked"' : '').(isset($field['js'][$cValue]) ? ' '.$field['js'][$cValue] : '').' /><label class="t" for="'.$key.$cValue.'_on"> '.$cKey.'</label><br />';
					echo '<br />';
					break;

				case 'image':
					echo '
					<table cellspacing="0" cellpadding="0">
						<tr>';
						foreach ($field['list'] AS $theme)
							echo '<td class="center" style="width: 180px;">
							<input type="radio" name="'.$key.'" id="'.$key.'_'.$theme['name'].'_on" style="vertical-align: text-bottom;" value="'.$theme['name'].'"'.
							(_THEME_NAME_ == $theme['name'] ? 'checked="checked"' : '').' />
							<label class="t" for="'.$key.'_'.$theme['name'].'_on"> '.ucwords(strtolower($theme['name'])).'</label>
							</td>
							<td style="width: 8px;">&nbsp;</td>';
					echo '</tr><tr>';
					foreach ($field['list'] AS $theme)
						echo '<td class="center"  style="width: 180px;">
						<label class="t" for="'.$key.'_'.$theme['name'].'_on">
							<img src="../themes/'.$theme['name'].'/preview.jpg" alt="'.ucwords(strtolower($theme['name'])).'">
						</label>
						</td>
						<td style="width: 8px;">&nbsp;</td>';
					echo '</tr>
					</table><br />';
					break;

				case 'text':
				default:
					echo '<input type="'.$field['type'].'" size="'.(isset($field['size']) ? intval($field['size']) : 5).'" name="'.$key.'" value="'.$val.'" />';
			}
			echo ((isset($field['required']) AND $field['required'] AND !in_array($field['type'], array('image', 'radio')))  ? ' <sup>*</sup>' : '').(isset($field['desc']) ? '<p style="clear: both;">'.$field['desc'].'</p>' : '');
			if (!in_array($field['type'], array('image', 'radio')) OR isset($field['show']))
				echo '</div>';
		}
		
		/* End of specific div for emails settings */
		if (get_class($this) == 'AdminEmails')
			echo '<script type="text/javascript">if (getE(\'PS_MAIL_METHOD2_on\').checked) getE(\'smtp\').style.display = \'block\'; else getE(\'smtp\').style.display = \'none\';</script>
			</div>';
		
		echo '	<div align="center" style="margin-top: 20px;">
					<input type="submit" value="'.$this->l('   Save   ').'" name="submit'.ucfirst($name).$this->table.'" class="button" />
				</div>
				'.($required ? '<div class="small"><sup>*</sup> '.$this->l('required fields').'</div>' : '').'
			</fieldset>
		</form>';
	}
	
	/**
	  * Display general settings
	  */
	public function displayFormGeneral() { $this->_displayForm('General', $this->_fieldsGeneral); }
	
	/**
	  * Display themes settings
	  */
	public function displayFormThemes() { $this->_displayForm('Themes', $this->_fieldsTheme); }	
	
	/**
	  * Display shop settings
	  */
	public function displayFormShop() { $this->_displayForm('Shop', $this->_fieldsShop); }
}

?>
