<?php

/**
  * Tab class, Tabs.php
  * Tab management
  * @category classes
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */

class Tab extends ObjectModel
{
	/** @var string Displayed name*/	
	public		$name;
	
	/** @var string Class and file name*/	
	public		$class_name;
	
	/** @var integer parent ID */	
	public		$id_parent;
	
	protected	$fieldsRequired = array('class_name');
	protected	$fieldsSize = array('class_name' => 64, 'icon' => 64);
	protected	$fieldsValidate = array('id_parent' => 'isUnsignedInt');
	
	protected	$fieldsRequiredLang = array('name');
	protected	$fieldsSizeLang = array('name' => 32);	
	protected	$fieldsValidateLang = array('name' => 'isGenericName');	
	
	protected 	$table = 'tab';
	protected 	$identifier = 'id_tab';	
	
	public function getFields()
	{
		parent::validateFields();
		$fields['class_name'] = pSQL($this->class_name);
		$fields['id_parent'] = intval($this->id_parent);
		return $fields;
	}	
	
	public function getTranslationsFieldsChild()
	{
		parent::validateFieldsLang();
		return parent::getTranslationsFields(array('name'));
	}
	
	public function add($autodate = true, $nullValues = false)
	{
		if (parent::add($autodate, $nullValues))
		{
			global $cookie;
			return Db::getInstance()->Execute('
			INSERT INTO `'._DB_PREFIX_.'access` (`id_profile`, `id_tab`, `view`, `add`, `edit`, `delete`)
			VALUES ('.((is_object($cookie) AND isset($cookie->profile)) ? intval($cookie->profile) : 1).', '.intval($this->id).', 1, 1, 1, 1)');
		}
		return false;
	}

	/**
	 * Get tab id
	 *
	 * @return integer tab id
	 */
	static public function getCurrentTabId()
	{
	 	if ($result = Db::getInstance()->getRow('SELECT `id_tab` FROM `'._DB_PREFIX_.'tab` WHERE LOWER(class_name)=\''.pSQL(strtolower(Tools::getValue('tab'))).'\''))
		 	return $result['id_tab'];
 		return -1;
	}
	
	/**
	 * Get tab parent id
	 *
	 * @return integer tab parent id
	 */
	static public function getCurrentParentId()
	{
	 	if ($result = Db::getInstance()->getRow('SELECT `id_parent` FROM `'._DB_PREFIX_.'tab` WHERE LOWER(class_name)=\''.pSQL(strtolower(Tools::getValue('tab'))).'\''))
		 	return $result['id_parent'];
 		return -1;
	}

	/**
	 * Get tabs
	 *
	 * @return array tabs
	 */
	static public function getTabs($id_lang, $id_parent = null)
	{
		/* Tabs selection */
		return Db::getInstance()->ExecuteS('
		SELECT *
		FROM `'._DB_PREFIX_.'tab` t
		LEFT JOIN `'._DB_PREFIX_.'tab_lang` tl ON (t.`id_tab` = tl.`id_tab` AND tl.`id_lang` = '.intval($id_lang).')
		'.($id_parent !== null ? 'WHERE t.`id_parent` = '.intval($id_parent) : '').'
		ORDER BY tl.`id_tab` ASC');		
	}
}

?>