<?php

class Cheque extends PaymentModule
{
    private $_html = '';
    private $_postErrors = array();
    
    public  $chequeName;
    public  $address;
    
    function __construct()
    {
        $this->name = 'cheque';
        $this->tab = 'Payment';
        $this->version = 1.1;
        
        $config = Configuration::getMultiple(array('CHEQUE_NAME', 'CHEQUE_ADDRESS'));
		if (isset($config['CHEQUE_NAME']))
			$this->chequeName = $config['CHEQUE_NAME'];
		if (isset($config['CHEQUE_ADDRESS']))
			$this->address = $config['CHEQUE_ADDRESS'];

		$this->_translations = array(
			'FR' => array(
				'Name and address must be configured in order to use this module correctly' => 'Le nom et l\'adresse doivent &ecirc;tre renseign&eacute;s pour utiliser le module',
				'Module accepting payments by cheque' => 'Module acceptant les paiements par ch&egrave;que', 
				'name is required.' => 'Un nom est requis.',
				'address is required.' => 'Une adresse est requise.',
				'This module allows you to accept payments by cheques.' => 'Ce module vous permet d\'accepter les paiements par ch&egrave;que.',
				'Confirm manually your order as soon as you receive this cheque.' => 'Vous devez confirmer manuellement votre commande d&egrave;s que vous recevez ce ch&egrave;que.',
				'If the client chooses this payment mode, the order will change its status into a "Waiting for payment" status.' => 'Si le client choisi ce mode de paiement, la commande passera automatiquement en statut "Attente du paiement".',
				'Name' => 'Nom',
				'Address' => 'Adresse',
				'Please contact us to obtain it.' => 'Veuillez nous contacter pour obtenir celle-ci.',
				'Order summation' => 'R&eacute;capitulatif de commande',
				'Cheque payment' => 'Paiement par ch&egrave;que',
				'You have to send us a cheque of an amount of ' => 'Merci de nous faire parvenir un ch&egrave;que de ',
				'to the account of' => '&agrave; l\'ordre de ',
				'to the following address' => '&agrave; l\'adresse suivante',
				'Your order will be sent as soon as we received your settlement.' => 'Votre commande vous sera exp&eacute;di&eacute;e d&egrave;s r&eacute;ception de votre r&egrave;glement.',
				'Choose another payment method' => 'Choisir un autre moyen de paiment',
				'I valid my order' => 'Je valide ma commande',
				'Pay by cheque (order process will be longer)' => 'Payer par ch&egrave;que (le traitement de la commande sera plus long)',
				'Your order on ' => 'Votre commande sur ',
				' have been registered successfuly.' => ' &agrave; bien &eacute;t&eacute; enregistr&eacute;e.',
				'You can send us your cheque of ' => 'Vous pouvez nous faire parvenir votre ch&egrave;que de ',
				'For any extra question or information, please contact our' => 'Pour toute question ou renseignement compl&eacute;mentaire, merci de contacter notre',
				'customer support' => 'service client',
				'We noticed a trouble during your order. If you think it is an error, you can contact our' => 'Nous avons constat&eacute; un probl&egrave;me lors de votre commande. Si vous pensez que c\'est une erreur, vous pouvez contacter notre',
				'Please do not forget to confirm your order by clicking CONFIRM button' => 'S\'il vous plait, n\'oubliez pas de confirmer votre commande en cliquant sur le bouton CONFIRMER', 
				'Update settings' => 'Mettre &agrave; jour',
				'Settings updated' => 'Mise &agrave; jour r&eacute;ussie'
			)
		);

        parent::__construct();
        
        /* The parent construct is required for translations */
        $this->displayName = $this->l('Cheque');
        $this->description = $this->l('Module accepting payments by cheque');
		if (!isset($this->address) OR !isset($this->address))
			$this->warning = $this->l('Name and address must be configured in order to use this module correctly');
    }
    
    function install()
    {
        parent::install();
        $this->registerHook('payment');
        $this->registerHook('paymentReturn');
    }

    function uninstall()
    {
		Configuration::deleteByName('CHEQUE_NAME');
		Configuration::deleteByName('CHEQUE_ADDRESS');
        parent::uninstall();
    }
    
    private function _postValidation()
    {
        if (empty($_POST['name']))
            $this->_postErrors[] = $this->l('name is required.');
        elseif (empty($_POST['address']))
            $this->_postErrors[] = $this->l('address is required.');
    }
    
    private function _postProcess()
    {
		Configuration::updateValue('CHEQUE_NAME', $_POST['name']);
		Configuration::updateValue('CHEQUE_ADDRESS', $_POST['address']);

        $this->_html .= '<div class="conf confirm"><img src="../img/admin/ok.gif" alt="'.$this->l('ok').'" /> '.$this->l('Settings updated').'</div>';
    }
    
    private function _displayCheque()
    {
        $this->_html .= '
        <p><b>'.$this->l('This module allows you to accept payments by cheques.').'</b><br /><br />
        '.$this->l('Confirm manually your order as soon as you receive this cheque.').'<br />'.
        $this->l('If the client chooses this payment mode, the order will change its status into a "Waiting for payment" status.').'</p><br />';
    }
    
    private function _displayForm()
    {
			if (!isset($_POST['btnSubmit']))
        {
					$_POST['name'] = $this->chequeName;
					$_POST['address'] = $this->address;
        }
			
        $this->_html .=
        '<fieldset><form action="" method="post">
            <table border="0" width="500" cellpadding="0" cellspacing="0" id="form">
          		<tr><td width="130" style="height: 35px;">'.$this->l('Name').'</td><td><input type="text" name="name" value="'.(isset($_POST['name']) ? $_POST['name'] : '').'" style="width: 300px;" /></td></tr>
          		<tr><td width="130" style="vertical-align: top;">'.$this->l('Address').'</td>
                  <td><textarea name="address" rows="3" cols="53">'.(isset($_POST['address']) ? $_POST['address'] : $this->l('Please contact us to obtain it.')).'</textarea></td></tr>
                <tr><td colspan="2" align="center"><br /><input class="button" name="btnSubmit" value="'.$this->l('Update settings').'" type="submit" /></td></tr>
            </table>
        </form></fieldset>';
    }

    function getContent()
    {
        $this->_html = '<h2>'.$this->displayName.'</h2>';

        if (!empty($_POST))
        {
            $this->_postValidation();
            if (!count($this->_postErrors))
                $this->_postProcess();
            else
                foreach ($this->_postErrors AS $err)
                    $this->_html .= '<div class="alert error">'. $err .'</div>';
        }
        else
            $this->_html .= '<br />';

        $this->_displayCheque();
        $this->_displayForm();

        return $this->_html;
    }
       
	function execPayment($cart)
	{
		global $cookie;
		
		$isoCode = Language::getIsoById(intval($cookie->id_lang));
		$total = number_format($cart->getOrderTotal(true, 3), 2, '.', '');
		$this->_html = '
		<h1>'.$this->l('Order summation').'</h1>
		<h2 class="cheque_module">'.$this->l('Cheque payment').'</h2>
		<form action="'.__PS_BASE_URI__.'modules/'.$this->name.'/validation.php" method="post">
			<input type="hidden" name="amount" value="'.$total.'" />
			<img src="'.__PS_BASE_URI__.'modules/'.$this->name.'/cheque.jpg" alt="'.$this->l('cheque').'" /><br /><br />
			'.$this->l('You have to send us a cheque of an amount of ').'<b>'.$total.' &euro;</b> '.
			$this->l('to the account of').' <b>'.($this->chequeName ? $this->chequeName : '___________').'</b>, '.
			$this->l('to the following address').' :<br /><br /><b>'.($this->address ? nl2br2($this->address) : '___________').'</b><br /><br />'.
			$this->l('Your order will be sent as soon as we received your settlement.').'<br /><b>'.$this->l('Please do not forget to confirm your order by clicking CONFIRM button').'.</b><br /><br /><br />
			<span style="float: left"><a href="'.__PS_BASE_URI__.'order.php?step=3"><input type="image" name="submit" value="'.$this->l('Choose another payment method').'" src="back-'.$isoCode.'.gif" style="vertical-align: middle;" /></a></span>
			<span style="float: right;"><input type="image" name="submit" value="'.$this->l('I valid my order').'" src="confirm-'.$isoCode.'.gif" style="vertical-align: middle;" /></span>
		</form>';
		return $this->_html;
	}
	   
    function hookPayment($params)
    {
        $this->_html = '
        <div class="payment_module">
			<table><tr><td style="width: 160px; height: 40px;">
				<a href="'.__PS_BASE_URI__.'modules/'.$this->name.'/payment.php"><img src="'.__PS_BASE_URI__.'modules/'.$this->name.'/cheque.jpg" alt="" title="" /></a>
			</td><td><a href="'.__PS_BASE_URI__.'modules/'.$this->name.'/payment.php"><b>'.$this->l('Pay by cheque (order process will be longer)').'</b></a>
			</td></tr></table>
		</div>';
        return $this->_html;
    }
    
    function hookPaymentReturn($params)
    {
		$state = $params['objOrder']->getCurrentState();
		if ($state == 1 OR $state == 8 OR $state == 10)
			$this->_html = '<br />'.
			$this->l('Your order on ').Configuration::get('PS_SHOP_NAME').$this->l(' have been registered successfuly.').'<br /><br />'.
			$this->l('You can send us your cheque of ').'<b>'.$params['total_to_pay'].' '.$params['currency'].'</b> '.
			$this->l('to the account of').'<b>'.$this->chequeName.'</b> '.
			$this->l('to the following address').' :<br /><br /><b>'.nl2br2($this->address).'</b><br /><br />'.
			$this->l('For any extra question or information, please contact our').' <a href="'.__PS_BASE_URI__.'contact-form.php">'.$this->l('customer support').'</a>.<br /><br />';
		else
			$this->_html =
			$this->l('We noticed a trouble during your order. If you think it is an error, you can contact our').' 
			<a href="'.__PS_BASE_URI__.'contact-form.php">'.$this->l('customer support').'</a>.<br /><br />';
			
        return $this->_html;
    }
}

?>
